@@ -1,54 +1,9 @@
-#ifndef MISC_CALLBACKS_H
-#define MISC_CALLBACKS_H
+#ifndef MISC_CALLBACS_H
+#define MISC_CALLBACS_H
 
 #include "bygfoot.h"
-#include "variables.h"
-
-/************************************************************
- * callbacks for the live game window                       *
- ************************************************************/
-
-void
-on_button_live_close_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-/************************************************************
- * callbacks for the font selection window                  *
- ************************************************************/
-
-void
-on_button_font_sel_ok_clicked          (GtkButton       *button,
-                                        gpointer         user_data);
-
-
-void
-on_button_font_sel_apply_clicked       (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_button_font_sel_cancel_clicked      (GtkButton       *button,
-                                        gpointer         user_data);
-
-/************************************************************
- * callbacks for the file selection window                  *
- ************************************************************/
-
-void
-on_button_fsel_ok_clicked              (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_button_fsel_cancel_clicked          (GtkButton       *button,
-                                        gpointer         user_data);
-
-gboolean
-on_fsel_window_delete_event            (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-/************************************************************
- * callbacks for the team selection window                  *
- ************************************************************/
+#include "misc_interface.h"
+#include "support.h"
 
 void
 on_team_selection_cancel_clicked       (GtkButton       *button,
@@ -59,7 +14,6 @@ on_team_selection_tv_row_activated     (GtkTreeView     *treeview,
                                         GtkTreePath     *path,
                                         GtkTreeViewColumn *column,
                                         gpointer         user_data);
-
 void
 on_team_selection_ok_clicked           (GtkButton       *button,
                                         gpointer         user_data);
@@ -68,59 +22,17 @@ void
 on_team_selection_load_clicked         (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_radiobutton_country_toggled        (GtkToggleButton *togglebutton,
-				       gpointer         user_data);
-
-void
-on_button_select_country_file_clicked  (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_checkbutton_load_randomly_toggled   (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
-/************************************************************
- * callbacks for the popup window                           *
- ************************************************************/
-
-
-
-void
-on_button_popup_ok_clicked             (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_button_popup_cancel_clicked         (GtkButton       *button,
-                                        gpointer         user_data);
-
 gboolean
-on_popup_window_delete_event           (GtkWidget       *widget,
+on_button_font_sel_cancel_clicked      (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data);
 
 void
-on_popup_check_toggled                 (GtkToggleButton *togglebutton,
+on_button_font_sel_ok_clicked          (GtkButton       *button,
                                         gpointer         user_data);
 
 void
-on_button_popup_close_clicked          (GtkButton       *button,
-                                        gpointer         user_data);
-
-/************************************************************
- * callbacks for the help window                            *
- ************************************************************/
-
-void
-on_button_help_close_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_button_start_editor_clicked         (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_checkbutton_only_names_toggled      (GtkToggleButton *togglebutton,
+on_button_font_sel_apply_clicked       (GtkButton       *button,
                                         gpointer         user_data);
 
 gboolean
@@ -128,4 +40,78 @@ on_live_window_delete_event            (GtkWidget       *widget,
                                         GdkEvent        *event,
                                         gpointer         user_data);
 
+void
+on_button_live_close_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button_pause_clicked                (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button_resume_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+
+void
+on_spinbutton_speed_value_changed      (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_button_add_player_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+
+gboolean
+on_treeview_users_button_press_event   (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_entry_player_name_activate          (GtkEntry        *entry,
+                                        gpointer         user_data);
+
+void
+on_spinbutton_capacity_value_changed   (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_spinbutton_safety_value_changed     (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_button_stadium_ok_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_button_stadium_cancel_clicked       (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_spinbutton_capacity_button_press_event
+                                        (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+void
+on_button_startup_resume_clicked       (GtkButton       *button,
+                                        gpointer         user_data);
+
+gboolean
+on_window_stadium_delete_event         (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+void
+on_combo_country_changed               (GtkComboBox     *combobox,
+                                        gpointer         user_data);
+
+void
+on_spinbutton_verbosity_value_changed  (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+gboolean
+on_spinbutton_speed_button_press_event (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
 #endif
